@@ -34,6 +34,7 @@ from equilibrator_cache.exceptions import MissingDissociationConstantsException
 from equilibrator_cache.thermodynamic_constants import default_pMg
 
 from . import CCModelParameters, Preprocessor
+from .linalg import LINALG
 
 
 logger = logging.getLogger(__name__)
@@ -51,13 +52,13 @@ class GibbsEnergyPredictor(object):
 
         parameters : CCModelParameters
             Optional CC parameters. If not provided, the parameters are
-            automatically downloaded from quilt.
+            automatically downloaded from Zenodo.
         rmse_inf : Qunatity
             another parameter determining the uncertainty we associate
             with reactions that are not covered at all (not by RC nor GC)
             (Default value = 1e5 kJ/mol)
         """
-        self.params = parameters or CCModelParameters.from_quilt()
+        self.params = parameters or CCModelParameters.from_zenodo()
 
         if rmse_inf is not None:
             assert rmse_inf.check(
@@ -70,7 +71,7 @@ class GibbsEnergyPredictor(object):
 
     def get_compound_prediction(
         self, compound: Compound
-    ) -> Tuple[Optional[float], Optional[np.ndarray]]:
+    ) -> Tuple[Optional[float], Optional[np.ndarray], Optional[np.ndarray]]:
         """Get the (mu, sigma) predictions of a compound's formation energy."""
         return self.preprocess.get_compound_prediction(compound)
 
@@ -83,14 +84,60 @@ class GibbsEnergyPredictor(object):
         """
         return self.preprocess.get_reaction_prediction(reaction)
 
-    def get_reaction_prediction_multi(
-        self, reactions: List[Reaction]
-    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-        """Get the (mu, sigma) predictions of a reaction's energy.
+    def combine_uncertainties(
+        self,
+        sigma_fin: np.ndarray,
+        sigma_inf: np.ndarray,
+        sigma_res: np.ndarray,
+        uncertainty_representation: str = "cov",
+    ) -> Q_:
+        """Calculate the transformed reaction energies of a list of reactions.
+
+        Parameters
+        ----------
+        sigmas_fin : np.array
+            a matrix whose columns are the square root vectors (one for each
+            reaction) of the uncertainty
+        sigmas_inf : np.array
+            a matrix whose columns represent the infinite-uncertainty
+            eigenvalues of the covariance
+        sigma_res : np.array
+            another matrix with the square root of the covariance corresponding
+            to the 'unknown' compounds (i.e. where the uncertainty is infinite)
+        uncertainty_representation : str
+            which representation to use for the uncertainties. 'cov' would
+            return a full covariance matrix. 'sqrt' would return a sqaure root
+            of the covariance, based on the uncertainty vectors.
+            'fullrank' would return a full-rank square root of the covariance
+            which is a compressed form of the 'sqrt' result.
+            (Default value: 'cov')
+
+        Returns
+        -------
+        dg_uncertainty : Quantity
+            the uncertainty co-variance matrix
+            (in either 'cov', 'sqrt' or 'fullrank' format)
 
-        See the Preprocessor class for details.
         """
-        return self.preprocess.get_reaction_prediction_multi(reactions)
+        sigma = np.hstack(
+            [
+                sigma_fin,
+                self.preprocess.RMSE_inf * sigma_inf,
+                self.preprocess.RMSE_inf * sigma_res,
+            ]
+        )
+
+        if uncertainty_representation == "cov":
+            dg_uncertainty = Q_(sigma @ sigma.T, "(kJ/mol)**2")
+        elif uncertainty_representation == "sqrt":
+            dg_uncertainty = Q_(sigma, "kJ/mol")
+        elif uncertainty_representation == "fullrank":
+            dg_uncertainty = Q_(LINALG.qr_rank_deficient(sigma.T).T, "kJ/mol")
+        else:
+            raise ValueError(
+                "uncertainty_representation must be 'cov', 'sqrt' or 'fullrank'"
+            )
+        return dg_uncertainty
 
     def standard_dgf(self, compound: Compound) -> ureg.Measurement:
         """Calculate the chemical formation energy of the major MS at pH 7.
@@ -114,11 +161,14 @@ class GibbsEnergyPredictor(object):
             (where dG0_cc is the mean of that Gaussian).
 
         """
-        mu, sigma = self.get_compound_prediction(compound)
+        mu, sigma_fin, sigma_inf = self.get_compound_prediction(compound)
         if mu is None:
             return Q_(0, "kJ/mol").plus_minus(self.preprocess.RMSE_inf)
         else:
-            return Q_(mu, "kJ/mol").plus_minus(np.linalg.norm(sigma, 2))
+            std = np.linalg.norm(
+                sigma_fin, 2
+            ) + self.preprocess.RMSE_inf * np.linalg.norm(sigma_inf, 2)
+            return Q_(mu, "kJ/mol").plus_minus(std)
 
     def standard_dg(self, reaction: Reaction) -> ureg.Measurement:
         r"""Calculate the chemical reaction energy.
@@ -139,15 +189,20 @@ class GibbsEnergyPredictor(object):
             calculate the 95% confidence interval, multiply the error by 1.96
 
         """
-        mu, sigma, residual = self.get_reaction_prediction(reaction)
+        mu, sigma_fin, sigma_inf, residual = self.get_reaction_prediction(
+            reaction
+        )
         if residual:
             return Q_(0, "kJ/mol").plus_minus(self.preprocess.RMSE_inf)
         else:
-            return Q_(mu, "kJ/mol").plus_minus(np.linalg.norm(sigma, 2))
+            std = np.linalg.norm(
+                sigma_fin, 2
+            ) + self.preprocess.RMSE_inf * np.linalg.norm(sigma_inf, 2)
+            return Q_(mu, "kJ/mol").plus_minus(std)
 
     def standard_dg_multi(
-        self, reactions: List[Reaction]
-    ) -> Tuple[np.ndarray, np.ndarray]:
+        self, reactions: List[Reaction], uncertainty_representation: str = "cov"
+    ) -> Tuple[Q_, Q_]:
         r"""Calculate the chemical reaction energies for a list of reactions.
 
         Using the major microspecies of each of the reactants.
@@ -156,25 +211,41 @@ class GibbsEnergyPredictor(object):
         ----------
         reactions : List[Reaction]
             a list of Reaction objects
-
+        uncertainty_representation : str
+            which representation to use for the uncertainties. 'cov' would
+            return a full covariance matrix. 'sqrt' would return a sqaure root
+            of the covariance, based on the uncertainty vectors.
+            'fullrank' would return a full-rank square root of the covariance
+            which is a compressed form of the 'sqrt' result.
+            (Default value: 'cov')
 
         Returns
         -------
-        standard_dg : np.ndarray
+        standard_dg : Quantity
             the array of Component Contribution estimates for the reactions'
             untransformed :math:`\Delta G` in kJ/mol,
             (i.e. using the major MS at pH 7 for each of the reactants).
-        cov_dg : np.ndarray
+        cov_dg : Quantity
             the covariance matrix of the standard errors of the estimates.
             one can use the eigenvectors of the matrix to define a confidence
             high-dimensional space, or use U as the covariance of a Gaussian
             used for sampling (where cov_dg is the mean of that Gaussian).
 
         """
-        mu, sigma, residual = self.get_reaction_prediction_multi(reactions)
+        (
+            mu,
+            sigma_fin,
+            sigma_inf,
+            sigma_res,
+        ) = self.preprocess.get_reaction_prediction_multi(reactions)
+
+        dg_uncertainty = self.combine_uncertainties(
+            sigma_fin, sigma_inf, sigma_res, uncertainty_representation
+        )
+
         standard_dg = Q_(mu, "kJ/mol")
-        cov_dg = Q_(sigma @ sigma.T + residual.T @ residual, "(kJ/mol)**2")
-        return standard_dg, cov_dg
+
+        return standard_dg, dg_uncertainty
 
     @ureg.check(None, None, "", "[concentration]", "[temperature]", "")
     def standard_dgf_prime(
@@ -281,7 +352,7 @@ class GibbsEnergyPredictor(object):
         temperature : Quantity
             the temperature
         p_mg: Quantity, optional
-             (Default value = default_pMg)
+            (Default value = default_pMg)
 
         Returns
         -------
